@@ -54,6 +54,14 @@ V1_BLOCK_CONFIGS = {
 }
 
 V2_BLOCK_CONFIGS = {
+    "b0": {  # width 1.0, depth 1.0
+        "first_conv_filter": 32,
+        "expands": [1, 4, 4, 4, 6, 6],
+        "out_channels": [16, 32, 48, 96, 112, 192],
+        "depthes": [1, 2, 2, 3, 5, 8],
+        "strides": [1, 2, 2, 2, 1, 2],
+        "use_ses": [0, 0, 0, 1, 1, 1],
+    },
     "b1": {  # width 1.0, depth 1.1
         "first_conv_filter": 32,
         "expands": [1, 4, 4, 4, 6, 6],
@@ -277,8 +285,8 @@ def EfficientNetV2(
     inputs = Input(shape=input_shape)
     if include_preprocessing:
         channel_axis = 1 if K.image_data_format() == "channels_first" else -1
-        nn = keras.layers.Rescaling(1.0 / 255.0)(inputs)
-        nn = keras.layers.Normalization(mean=[0.485, 0.456, 0.406], variance=[0.229, 0.224, 0.225], axis=channel_axis)(nn)
+        nn = keras.layers.experimental.preprocessing.Rescaling(1.0 / 255.0)(inputs)
+        nn = keras.layers.experimental.preprocessing.Normalization(mean=[0.485, 0.456, 0.406], variance=[0.229, 0.224, 0.225], axis=channel_axis)(nn)
     else:
         nn = inputs
     out_channel = _make_divisible(first_conv_filter, 8)
